def add_numbers(num1,num2):
    return num1 + num2


def minus_numbers(num1,num2):
    return num1 - num2


def multiply_numbers(num1,num2):
    return num1 * num2


def devide_numbers(num1,num2):
    return num1 / num2
